@@ -27,7 +27,7 @@ from ._log_levels import _LEVEL_TO_NAME, _NAME_TO_LEVEL, add_log_level
 from .contextvars import merge_contextvars
 from .exceptions import DropEvent
 from .processors import StackInfoRenderer
-from .types import Context, EventDict, ExcInfo, Processor, WrappedLogger
+from .typing import Context, EventDict, ExcInfo, Processor, WrappedLogger
 
 
 __all__ = [
@@ -77,7 +77,7 @@ def recreate_defaults(*, log_level: int | None = logging.NOTSET) -> None:
             format="%(message)s",
             stream=sys.stdout,
             level=log_level,
-            **kw,  # type: ignore
+            **kw,  # type: ignore[arg-type]
         )
 
     _config.reset_defaults()
@@ -100,7 +100,7 @@ _SENTINEL = object()
 class _FixedFindCallerLogger(logging.Logger):
     """
     Change the behavior of `logging.Logger.findCaller` to cope with
-    ``structlog``'s extra frames.
+    *structlog*'s extra frames.
     """
 
     def findCaller(
@@ -114,10 +114,7 @@ class _FixedFindCallerLogger(logging.Logger):
         """
         sinfo: str | None
         f, name = _find_first_app_frame_and_name(["logging"])
-        if stack_info:
-            sinfo = _format_stack(f)
-        else:
-            sinfo = None
+        sinfo = _format_stack(f) if stack_info else None
 
         return f.f_code.co_filename, f.f_lineno, f.f_code.co_name, sinfo
 
@@ -137,6 +134,9 @@ class BoundLogger(BoundLoggerBase):
 
     It also contains a bunch of properties that pass-through to the wrapped
     `logging.Logger` which should make it work as a drop-in replacement.
+
+    .. versionadded:: 23.1.0
+       Async variants `alog()`, `adebug()`, `ainfo()`, and so forth.
     """
 
     _logger: logging.Logger
@@ -145,7 +145,7 @@ class BoundLogger(BoundLoggerBase):
         """
         Return a new logger with *new_values* added to the existing ones.
         """
-        return super().bind(**new_values)  # type: ignore
+        return super().bind(**new_values)  # type: ignore[return-value]
 
     def unbind(self, *keys: str) -> BoundLogger:
         """
@@ -153,7 +153,7 @@ class BoundLogger(BoundLoggerBase):
 
         :raises KeyError: If the key is not part of the context.
         """
-        return super().unbind(*keys)  # type: ignore
+        return super().unbind(*keys)  # type: ignore[return-value]
 
     def try_unbind(self, *keys: str) -> BoundLogger:
         """
@@ -161,7 +161,7 @@ class BoundLogger(BoundLoggerBase):
 
         .. versionadded:: 18.2.0
         """
-        return super().try_unbind(*keys)  # type: ignore
+        return super().try_unbind(*keys)  # type: ignore[return-value]
 
     def new(self, **new_values: Any) -> BoundLogger:
         """
@@ -171,7 +171,7 @@ class BoundLogger(BoundLoggerBase):
         those wrapped by `structlog.threadlocal.wrap_dict` when threads
         are re-used.
         """
-        return super().new(**new_values)  # type: ignore
+        return super().new(**new_values)  # type: ignore[return-value]
 
     def debug(self, event: str | None = None, *args: Any, **kw: Any) -> Any:
         """
@@ -246,10 +246,8 @@ class BoundLogger(BoundLoggerBase):
 
         return super()._proxy_to_logger(method_name, event=event, **event_kw)
 
-    #
-    # Pass-through attributes and methods to mimick the stdlib's logger
+    # Pass-through attributes and methods to mimic the stdlib's logger
     # interface.
-    #
 
     @property
     def name(self) -> str:
@@ -377,6 +375,89 @@ class BoundLogger(BoundLoggerBase):
         """
         return self._logger.getChild(suffix)
 
+    # Non-Standard Async
+    async def _dispatch_to_sync(
+        self,
+        meth: Callable[..., Any],
+        event: str,
+        args: tuple[Any, ...],
+        kw: dict[str, Any],
+    ) -> None:
+        """
+        Merge contextvars and log using the sync logger in a thread pool.
+        """
+        ctx = contextvars.copy_context()
+
+        await asyncio.get_running_loop().run_in_executor(
+            None,
+            lambda: ctx.run(lambda: meth(event, *args, **kw)),
+        )
+
+    async def adebug(self, event: str, *args: Any, **kw: Any) -> None:
+        """
+        Log using `debug()`, but asynchronously in a separate thread.
+
+        .. versionadded:: 23.1.0
+        """
+        await self._dispatch_to_sync(self.debug, event, args, kw)
+
+    async def ainfo(self, event: str, *args: Any, **kw: Any) -> None:
+        """
+        Log using `info()`, but asynchronously in a separate thread.
+
+        .. versionadded:: 23.1.0
+        """
+        await self._dispatch_to_sync(self.info, event, args, kw)
+
+    async def awarning(self, event: str, *args: Any, **kw: Any) -> None:
+        """
+        Log using `warning()`, but asynchronously in a separate thread.
+
+        .. versionadded:: 23.1.0
+        """
+        await self._dispatch_to_sync(self.warning, event, args, kw)
+
+    async def aerror(self, event: str, *args: Any, **kw: Any) -> None:
+        """
+        Log using `error()`, but asynchronously in a separate thread.
+
+        .. versionadded:: 23.1.0
+        """
+        await self._dispatch_to_sync(self.error, event, args, kw)
+
+    async def acritical(self, event: str, *args: Any, **kw: Any) -> None:
+        """
+        Log using `critical()`, but asynchronously in a separate thread.
+
+        .. versionadded:: 23.1.0
+        """
+        await self._dispatch_to_sync(self.critical, event, args, kw)
+
+    afatal = acritical
+
+    async def aexception(self, event: str, *args: Any, **kw: Any) -> None:
+        """
+        Log using `exception()`, but asynchronously in a separate thread.
+
+        .. versionadded:: 23.1.0
+        """
+        # To make `log.exception("foo") work, we have to check if the user
+        # passed an explicit exc_info and if not, supply our own.
+        if kw.get("exc_info", True) is True and kw.get("exception") is None:
+            kw["exc_info"] = sys.exc_info()
+
+        await self._dispatch_to_sync(self.exception, event, args, kw)
+
+    async def alog(
+        self, level: Any, event: str, *args: Any, **kw: Any
+    ) -> None:
+        """
+        Log using `log()`, but asynchronously in a separate thread.
+
+        .. versionadded:: 23.1.0
+        """
+        await self._dispatch_to_sync(partial(self.log, level), event, args, kw)
+
 
 def get_logger(*args: Any, **initial_values: Any) -> BoundLogger:
     """
@@ -384,7 +465,8 @@ def get_logger(*args: Any, **initial_values: Any) -> BoundLogger:
 
     .. warning::
 
-       Does **not** check whether you've configured ``structlog`` correctly!
+       Does **not** check whether -- or ensure that -- you've configured
+       *structlog* for standard library :mod:`logging`!
 
        See :doc:`standard-library` for details.
 
@@ -449,7 +531,7 @@ class AsyncBoundLogger:
     # we're a BindableLogger.
     # Instances would've been correctly recognized as such, however the class
     # not and we need the class in `structlog.configure()`.
-    @property  # type: ignore
+    @property  # type: ignore[no-redef]
     def _context(self) -> Context:
         return self.sync_bl._context
 
@@ -458,7 +540,7 @@ class AsyncBoundLogger:
             # logger, processors and context are within sync_bl. These
             # arguments are ignored if _sync_bl is passed. *vroom vroom* over
             # purity.
-            logger=None,  # type: ignore
+            logger=None,  # type: ignore[arg-type]
             processors=(),
             context={},
             _sync_bl=self.sync_bl.bind(**new_values),
@@ -468,7 +550,7 @@ class AsyncBoundLogger:
     def new(self, **new_values: Any) -> AsyncBoundLogger:
         return AsyncBoundLogger(
             # c.f. comment in bind
-            logger=None,  # type: ignore
+            logger=None,  # type: ignore[arg-type]
             processors=(),
             context={},
             _sync_bl=self.sync_bl.new(**new_values),
@@ -478,7 +560,7 @@ class AsyncBoundLogger:
     def unbind(self, *keys: str) -> AsyncBoundLogger:
         return AsyncBoundLogger(
             # c.f. comment in bind
-            logger=None,  # type: ignore
+            logger=None,  # type: ignore[arg-type]
             processors=(),
             context={},
             _sync_bl=self.sync_bl.unbind(*keys),
@@ -488,7 +570,7 @@ class AsyncBoundLogger:
     def try_unbind(self, *keys: str) -> AsyncBoundLogger:
         return AsyncBoundLogger(
             # c.f. comment in bind
-            logger=None,  # type: ignore
+            logger=None,  # type: ignore[arg-type]
             processors=(),
             context={},
             _sync_bl=self.sync_bl.try_unbind(*keys),
@@ -563,7 +645,7 @@ class LoggerFactory:
         whose names *start* with one of these.  For example, in pyramid
         applications you'll want to set it to
         ``["venusian", "pyramid.config"]``. This argument is
-        called *additional_ignores* in other APIs throughout `structlog`.
+        called *additional_ignores* in other APIs throughout *structlog*.
     """
 
     def __init__(self, ignore_frame_names: list[str] | None = None):
@@ -622,10 +704,10 @@ class PositionalArgumentsFormatter:
     ) -> EventDict:
         args = event_dict.get("positional_args")
 
-        # Mimick the formatting behaviour of the stdlib's logging
-        # module, which accepts both positional arguments and a single
-        # dict argument. The "single dict" check is the same one as the
-        # stdlib's logging module performs in LogRecord.__init__().
+        # Mimic the formatting behaviour of the stdlib's logging module, which
+        # accepts both positional arguments and a single dict argument. The
+        # "single dict" check is the same one as the stdlib's logging module
+        # performs in LogRecord.__init__().
         if args:
             if len(args) == 1 and isinstance(args[0], dict) and args[0]:
                 args = args[0]
@@ -661,8 +743,8 @@ def filter_by_level(
     """
     if logger.isEnabledFor(_NAME_TO_LEVEL[method_name]):
         return event_dict
-    else:
-        raise DropEvent
+
+    raise DropEvent
 
 
 def add_log_level_number(
@@ -703,7 +785,7 @@ def add_logger_name(
 
 
 _LOG_RECORD_KEYS = logging.LogRecord(
-    "name", 0, "pathname", 0, "msg", tuple(), None
+    "name", 0, "pathname", 0, "msg", (), None
 ).__dict__.keys()
 
 
@@ -793,35 +875,35 @@ def render_to_log_kwargs(
 
 class ProcessorFormatter(logging.Formatter):
     r"""
-    Call ``structlog`` processors on `logging.LogRecord`\s.
+    Call *structlog* processors on `logging.LogRecord`\s.
 
     This is an implementation of a `logging.Formatter` that can be used to
-    format log entries from both ``structlog`` and `logging`.
+    format log entries from both *structlog* and `logging`.
 
     Its static method `wrap_for_formatter` must be the final processor in
-    ``structlog``'s processor chain.
+    *structlog*'s processor chain.
 
     Please refer to :ref:`processor-formatter` for examples.
 
     :param foreign_pre_chain:
         If not `None`, it is used as a processor chain that is applied to
-        **non**-``structlog`` log entries before the event dictionary is passed
+        **non**-*structlog* log entries before the event dictionary is passed
         to *processors*. (default: `None`)
     :param processors:
-        A chain of ``structlog`` processors that is used to process **all** log
+        A chain of *structlog* processors that is used to process **all** log
         entries. The last one must render to a `str` which then gets passed on
         to `logging` for output.
 
-        Compared to ``structlog``'s regular processor chains, there's a few
+        Compared to *structlog*'s regular processor chains, there's a few
         differences:
 
         - The event dictionary contains two additional keys:
 
           #. ``_record``: a `logging.LogRecord` that either was created using
-             `logging` APIs, **or** is a wrapped ``structlog`` log entry
+             `logging` APIs, **or** is a wrapped *structlog* log entry
              created by `wrap_for_formatter`.
           #. ``_from_structlog``: a `bool` that indicates whether or not
-             ``_record`` was created by a ``structlog`` logger.
+             ``_record`` was created by a *structlog* logger.
 
           Since you most likely don't want ``_record`` and
           ``_from_structlog`` in your log files,  we've added
@@ -836,14 +918,14 @@ class ProcessorFormatter(logging.Formatter):
         ``True`` to keep it on the `logging.LogRecord`. (default: False)
     :param keep_stack_info: Same as *keep_exc_info* except for ``stack_info``.
         (default: False)
-    :param logger: Logger which we want to push through the ``structlog``
+    :param logger: Logger which we want to push through the *structlog*
         processor chain. This parameter is necessary for some of the
         processors like `filter_by_level`. (default: None)
     :param pass_foreign_args: If True, pass a foreign log record's
         ``args`` attribute to the ``event_dict`` under ``positional_args`` key.
         (default: False)
     :param processor:
-        A single ``structlog`` processor used for rendering the event
+        A single *structlog* processor used for rendering the event
         dictionary before passing it off to `logging`. Must return a `str`.
         The event dictionary does **not** contain ``_record`` and
         ``_from_structlog``.
@@ -877,7 +959,7 @@ class ProcessorFormatter(logging.Formatter):
         **kwargs: Any,
     ) -> None:
         fmt = kwargs.pop("fmt", "%(message)s")
-        super().__init__(*args, fmt=fmt, **kwargs)  # type: ignore
+        super().__init__(*args, fmt=fmt, **kwargs)  # type: ignore[misc]
 
         if processor and processors:
             raise TypeError(
@@ -903,7 +985,7 @@ class ProcessorFormatter(logging.Formatter):
 
     def format(self, record: logging.LogRecord) -> str:
         """
-        Extract ``structlog``'s `event_dict` from ``record.msg`` and format it.
+        Extract *structlog*'s `event_dict` from ``record.msg`` and format it.
 
         *record* has been patched by `wrap_for_formatter` first though, so the
          type isn't quite right.
@@ -913,18 +995,18 @@ class ProcessorFormatter(logging.Formatter):
         record = logging.makeLogRecord(record.__dict__)
 
         logger = getattr(record, "_logger", _SENTINEL)
-        meth_name = getattr(record, "_name", _SENTINEL)
+        meth_name = getattr(record, "_name", "__structlog_sentinel__")
 
-        if logger is not _SENTINEL and meth_name is not _SENTINEL:
+        if logger is not _SENTINEL and meth_name != "__structlog_sentinel__":
             # Both attached by wrap_for_formatter
             if self.logger is not None:
                 logger = self.logger
-            meth_name = record._name  # type: ignore
+            meth_name = record._name  # type: ignore[attr-defined]
 
             # We need to copy because it's possible that the same record gets
             # processed by multiple logging formatters.  LogRecord.getMessage
             # would transform our dict into a str.
-            ed = record.msg.copy()  # type: ignore
+            ed = record.msg.copy()  # type: ignore[attr-defined]
             ed["_record"] = record
             ed["_from_structlog"] = True
         else:
